bfCorrectV: Perform Bonferroni correction on a vector of p-values

View source: R/multiple_testing.R

bfCorrectVR Documentation

Perform Bonferroni correction on a vector of p-values

Description

This function performs Bonferroni correction on a vector of p-values.

Usage

bfCorrectV(pvals, nComp)

Arguments

pvals

A numeric vector.

nComp

Number of comparisons. In most situations, this parameter should not be changed.

Details

This function is implemented in order to allow users to perform Bonferroni correction with fewer comparisons than the number of elements in the vector, which is normally disallowed by the p.adjust function from stats. A use case is correcting the Seurat markers returned for each identity class by setting the number of comparisons to the number of classes.

Value

Bonferroni-corrected p-values


LISTO documentation built on April 25, 2026, 5:06 p.m.