buildSeuratMarkerList: Build a Seurat marker list ready to be used by LISTO

View source: R/seurat_demo.R

buildSeuratMarkerListR Documentation

Build a Seurat marker list ready to be used by LISTO

Description

This function builds a Seurat marker list ready to be used by LISTO. Requires Seurat (not automatically installed with LISTO).

Usage

buildSeuratMarkerList(seuratObj, col, logFCThr = 1, minPct = 0.2, ...)

Arguments

seuratObj

A Seurat object.

col

Seurat metadata column used for grouping.

logFCThr

Fold change threshold for testing.

minPct

The minimum fraction of in-cluster cells in which tested genes need to be expressed.

...

Additional arguments passed to Seurat::FindMarkers.

Value

A list consisting of data frames generated with Seurat::FindMarkers.

Examples

seuratPath <- system.file('extdata', 'seuratObj.qs2', package='LISTO')
seuratObj <- qs2::qs_read(seuratPath)
a <- buildSeuratMarkerList(seuratObj, 'Cell_Cycle', logFCThr=0.1)


LISTO documentation built on April 25, 2026, 5:06 p.m.