factorialPrimePowers: Generate the prime factor decomposition of n factorial.

View source: R/factor_decomposition.R

factorialPrimePowersR Documentation

Generate the prime factor decomposition of n factorial.

Description

This function generates the prime factor decomposition of n factorial.

Usage

factorialPrimePowers(n)

Arguments

n

A positive integer.

Value

A vector in which positions represent prime numbers (that is, the first position corresponds to 2, the second position corresponds to 3, the third position corresponds to 5, etc.) and values represent their exponents in the factorial decomposition.

Examples

factorialPrimePowers(8)


LISTO documentation built on April 25, 2026, 5:06 p.m.