| filterItems | R Documentation |
This function filters items based on a provided cutoff.
filterItems(obj, numCol = NULL, cutoff = NULL, compFun = `>`)
obj |
A data frame with a numeric column, or a character vector. |
numCol |
The name of the numeric column used for data frame ordering. |
cutoff |
Cutoff for assessing item overlaps. |
compFun |
Comparison function. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.