generateCutoffs: Generate cutoffs for filtering overlaps

View source: R/cutoffs.R

generateCutoffsR Documentation

Generate cutoffs for filtering overlaps

Description

This function generates cutoffs for filtering overlaps

Usage

generateCutoffs(
  obj1,
  obj2,
  obj3 = NULL,
  numCol = NULL,
  isHighTop = TRUE,
  maxCutoffs = 5000
)

Arguments

obj1

A data frame with a numeric column, or a character vector.

obj2

A data frame with a numeric column, or a character vector.

obj3

A data frame with a numeric column, or a character vector.

numCol

The name of the numeric column used for data frame ordering.

isHighTop

Whether higher values in the numeric column correspond to top-ranked items.

maxCutoffs

Maximum number of cutoffs. If the input data frames contain more cutoffs than this value, only maxCutoffs linearly spaced cutoffs will be selected from the generated cutoff list.

Value

A numeric vector.


LISTO documentation built on April 25, 2026, 5:06 p.m.