getObjectValues: Extract numeric values from an input object

View source: R/cutoffs.R

getObjectValuesR Documentation

Extract numeric values from an input object

Description

This function extracts numeric values from an input object.

Usage

getObjectValues(obj, numCol = NULL, isHighTop = TRUE)

Arguments

obj

A data frame with a numeric column, or a character vector.

numCol

The name of the numeric column used for data frame ordering.

isHighTop

Whether higher values in the numeric column correspond to top-ranked items.


LISTO documentation built on April 25, 2026, 5:06 p.m.