mtCorrectHelper: Helper function for multiple comparison testing

View source: R/multiple_testing.R

mtCorrectHelperR Documentation

Helper function for multiple comparison testing

Description

This function is a helper for multiple comparison testing.

Usage

mtCorrectHelper(pvals, mtMethod, nComp)

Arguments

pvals

A numeric vector.

mtMethod

Multiple testing correction method. Choices are 'BY' (default) 'holm', hochberg', hommel', 'bonferroni', 'BH', 'fdr' and 'none'.

nComp

Number of comparisons. In most situations, this parameter should not be changed.

Value

Adjusted p-values.


LISTO documentation built on April 25, 2026, 5:06 p.m.