| probCounts2MN | R Documentation |
This function computes the probability that two subsets of sets M and N intersect in k points. Intersection sizes (M with N, A with N and B with M) must be provided.
probCounts2MN(intMN, intAN, intBM, k)
intMN |
Number of elements in the intersection of sets M and N. |
intAN |
Number of elements in the intersection of sets A (subset of M) and N. |
intBM |
Number of elements in the intersection of sets B (subset of N) and M. |
k |
Number of elements in the intersection of sets A and B. |
A numeric value in [0, 1] representing the probability that two subsets of sets M and N intersect in k points.
probCounts2MN(8, 6, 4, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.