probCounts3N: Compute the probability that three subsets of given sizes...

View source: R/prob_counts.R

probCounts3NR Documentation

Compute the probability that three subsets of given sizes intersect in k points

Description

This function computes the probability that three subsets of given sizes intersect in k points.

Usage

probCounts3N(a, b, c, n, k)

Arguments

a

Size of the first subset.

b

Size of the second subset.

c

Size of the third subset.

n

Size of the set.

k

Size of the intersection.

Value

A numeric value in [0, 1] representing the probability that three subsets of given sizes intersect in k points.

Examples

probCounts3N(8, 6, 10, 20, 3)


LISTO documentation built on April 25, 2026, 5:06 p.m.