pvalCounts3N: Compute the probability that three subsets of a set intersect...

View source: R/pval_counts.R

pvalCounts3NR Documentation

Compute the probability that three subsets of a set intersect in at least k points

Description

This function computes the probability that three subsets of a set intersect in at least k points.

Usage

pvalCounts3N(lenA, lenB, lenC, n, k)

Arguments

lenA

Size of the first subset.

lenB

Size of the second subset.

lenC

Size of the third subset.

n

Size of the set comprising the subsets.

k

Size of the intersection.

Value

A numeric value in [0, 1] representing the probability that three subsets of a set intersect in at least k points.

Examples

pvalCounts3N (300, 200, 250, 400, 180)


LISTO documentation built on April 25, 2026, 5:06 p.m.