pvalObjectsCore: Compute the p-value of overlap for two or three objects

View source: R/pval_objects.R

pvalObjectsCoreR Documentation

Compute the p-value of overlap for two or three objects

Description

This function computes the p-value of overlap for two or three objects.

Usage

pvalObjectsCore(
  obj1,
  obj2,
  obj3 = NULL,
  universe1,
  universe2 = NULL,
  numCol = NULL,
  cutoff = NULL,
  compFun = `>`,
  type = c("2N", "2MN", "3N")
)

Arguments

obj1

A data frame with a numeric column, or a character vector.

obj2

A data frame with a numeric column, or a character vector.

obj3

A data frame with a numeric column, or a character vector.

universe1

The set from which the items stored in obj1 are selected.

universe2

The set from which the items stored in obj2 are selected.

numCol

The name of the numeric column used for data frame ordering.

Value

A p-value.


LISTO documentation built on April 25, 2026, 5:06 p.m.