pvalSets2MN: Compute the p-value of intersection of two subsets of sets M...

View source: R/pval_sets.R

pvalSets2MNR Documentation

Compute the p-value of intersection of two subsets of sets M and N

Description

This function computes the p-value of intersection of two subsets of sets M and N.

Usage

pvalSets2MN(a, b, m, n)

Arguments

a

A character vector.

b

A character vector.

m

Set from which a is selected.

n

Set from which b is selected.

Details

A thin wrapper around pvalCounts2MN.

Value

A numeric value in [0, 1] representing the p-value of intersection of two subsets of sets M and N.

Examples

pvalSets2MN(LETTERS[seq(4, 10)],
LETTERS[seq(7, 15)],
LETTERS[seq(19)],
LETTERS[seq(6, 26)])


LISTO documentation built on April 25, 2026, 5:06 p.m.