runLISTO: Assess the overlap of two or three lists of objects.

View source: R/run_listo.R

runLISTOR Documentation

Assess the overlap of two or three lists of objects.

Description

This function assesses the overlap of two or three lists of objects (character vectors, or data frames having at least one numeric column).

Usage

runLISTO(
  list1,
  list2,
  list3 = NULL,
  universe1,
  universe2 = NULL,
  numCol = NULL,
  isHighTop = TRUE,
  maxCutoffs = 5000,
  mtMethod = c("BY", "holm", "hochberg", "hommel", "bonferroni", "BH", "fdr", "none"),
  pvalThr = NULL,
  nCores = 1,
  verbose = TRUE,
  ...
)

Arguments

list1

A list containing character vectors, or data frames having a numeric column.

list2

A list containing character vectors, or data frames having a numeric column.

list3

A list containing character vectors, or data frames having a numeric column.

universe1

Character vector; the set from which the items corresponding to the elements in list1 are selected.

universe2

Character vector; the set from which the items corresponding to the elements in list2 are selected.

numCol

The name of the numeric column used for data frame ordering.

isHighTop

Whether higher values in the numeric column correspond to top-ranked items.

maxCutoffs

Maximum number of cutoffs. If the input data frames contain more cutoffs than this value, only maxCutoffs linearly spaced cutoffs will be selected from the generated cutoff list.

mtMethod

Multiple testing correction method.

pvalThr

Threshold to filter the results based on the adjusted p-values. If NULL as default, no filtering will be performed.

nCores

Number of cores. If performing an overlap assessment between sets belonging to the same universe, it is recommended not to use parallelization (that is, leave this parameter as 1).

verbose

Logical; whether the output should be verbose.

...

Additional arguments passed to mtCorrectDF.

Value

A data frame listing the p-value and adjusted p-value for each overlap. Combinations of overlaps are represented through the first two (or three if list3 is not NULL) columns, while the penultimate column records the overlap p-values and the last column records the adjusted overlap p-values.

Examples

donorPath <- system.file('extdata', 'donorMarkers.qs2', package='LISTO')
donorMarkers <- qs2::qs_read(donorPath)[seq(3)]
labelPath <- system.file('extdata', 'labelMarkers.qs2', package='LISTO')
labelMarkers <- qs2::qs_read(labelPath)[seq(3)]
universe1Path <- system.file('extdata', 'universe1.qs2', package='LISTO')
universe1 <- qs2::qs_read(universe1Path)
res <-  runLISTO(donorMarkers, labelMarkers, universe1=universe1,
numCol='avg_log2FC')


LISTO documentation built on April 25, 2026, 5:06 p.m.