vChoose: Compute the prime factor decomposition of the binomial...

View source: R/vectors.R

vChooseR Documentation

Compute the prime factor decomposition of the binomial coefficient

Description

This function computes the prime factor decomposition of the binomial coefficient.

Usage

vChoose(n, k)

Arguments

n

Total number of elements.

k

Number of selected elements.

Value

A vector in which positions represent prime numbers (that is, the first position corresponds to 2, the second position corresponds to 3, the third position corresponds to 5, etc.) and values represent their exponents in the factorial decomposition.

Examples

vChoose(8, 4)


LISTO documentation built on April 25, 2026, 5:06 p.m.