View source: R/multiple_testing.R
| bfCorrectV | R Documentation |
This function performs Bonferroni correction on a vector of p-values.
bfCorrectV(pvals, nComp)
pvals |
A numeric vector. |
nComp |
Number of comparisons. In most situations, this parameter should not be changed. |
This function is implemented in order to allow users to perform
Bonferroni correction with fewer comparisons than the number of elements
in the vector, which is normally disallowed by the p.adjust function
from stats. A use case is correcting the Seurat markers returned
for each identity class by setting the number of comparisons to the number
of classes.
Bonferroni-corrected p-values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.