| buildSeuratMarkerList | R Documentation |
This function builds a Seurat marker list ready to be used by LISTO. Requires Seurat (not automatically installed with LISTO).
buildSeuratMarkerList(seuratObj, col, logFCThr = 1, minPct = 0.2, ...)
seuratObj |
A Seurat object. |
col |
Seurat metadata column used for grouping. |
logFCThr |
Fold change threshold for testing. |
minPct |
The minimum fraction of in-cluster cells in which tested genes need to be expressed. |
... |
Additional arguments passed to |
A list consisting of data frames generated with
Seurat::FindMarkers.
seuratPath <- system.file('extdata', 'seuratObj.qs2', package='LISTO')
seuratObj <- qs2::qs_read(seuratPath)
a <- buildSeuratMarkerList(seuratObj, 'Cell_Cycle', logFCThr=0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.