View source: R/factor_decomposition.R
| factorialPrimePowers | R Documentation |
This function generates the prime factor decomposition of n factorial.
factorialPrimePowers(n)
n |
A positive integer. |
A vector in which positions represent prime numbers (that is, the first position corresponds to 2, the second position corresponds to 3, the third position corresponds to 5, etc.) and values represent their exponents in the factorial decomposition.
factorialPrimePowers(8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.