| generateCutoffs | R Documentation |
This function generates cutoffs for filtering overlaps
generateCutoffs(
obj1,
obj2,
obj3 = NULL,
numCol = NULL,
isHighTop = TRUE,
maxCutoffs = 5000
)
obj1 |
A data frame with a numeric column, or a character vector. |
obj2 |
A data frame with a numeric column, or a character vector. |
obj3 |
A data frame with a numeric column, or a character vector. |
numCol |
The name of the numeric column used for data frame ordering. |
isHighTop |
Whether higher values in the numeric column correspond to top-ranked items. |
maxCutoffs |
Maximum number of cutoffs. If the input data frames
contain more cutoffs than this value, only |
A numeric vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.