| getObjectValues | R Documentation |
This function extracts numeric values from an input object.
getObjectValues(obj, numCol = NULL, isHighTop = TRUE)
obj |
A data frame with a numeric column, or a character vector. |
numCol |
The name of the numeric column used for data frame ordering. |
isHighTop |
Whether higher values in the numeric column correspond to top-ranked items. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.