View source: R/multiple_testing.R
| mtCorrectHelper | R Documentation |
This function is a helper for multiple comparison testing.
mtCorrectHelper(pvals, mtMethod, nComp)
pvals |
A numeric vector. |
mtMethod |
Multiple testing correction method. Choices are 'BY' (default) 'holm', hochberg', hommel', 'bonferroni', 'BH', 'fdr' and 'none'. |
nComp |
Number of comparisons. In most situations, this parameter should not be changed. |
Adjusted p-values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.