| probCounts3N | R Documentation |
This function computes the probability that three subsets of given sizes intersect in k points.
probCounts3N(a, b, c, n, k)
a |
Size of the first subset. |
b |
Size of the second subset. |
c |
Size of the third subset. |
n |
Size of the set. |
k |
Size of the intersection. |
A numeric value in [0, 1] representing the probability that three subsets of given sizes intersect in k points.
probCounts3N(8, 6, 10, 20, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.