| pvalCounts3N | R Documentation |
This function computes the probability that three subsets of a set intersect in at least k points.
pvalCounts3N(lenA, lenB, lenC, n, k)
lenA |
Size of the first subset. |
lenB |
Size of the second subset. |
lenC |
Size of the third subset. |
n |
Size of the set comprising the subsets. |
k |
Size of the intersection. |
A numeric value in [0, 1] representing the probability that three subsets of a set intersect in at least k points.
pvalCounts3N (300, 200, 250, 400, 180)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.