| pvalObjects | R Documentation |
This function assesses the overlap of two or three objects (character vectors, or data frames having a numeric column).
pvalObjects(
obj1,
obj2,
obj3 = NULL,
universe1,
universe2 = NULL,
numCol = NULL,
isHighTop = TRUE,
maxCutoffs = 5000,
mtMethod = c("BY", "holm", "hochberg", "hommel", "bonferroni", "BH", "fdr", "none"),
nCores = 1,
type = c("2N", "2MN", "3N")
)
obj1 |
A data frame with a numeric column, or a character vector. |
obj2 |
A data frame with a numeric column, or a character vector. |
obj3 |
A data frame with a numeric column, or a character vector. |
universe1 |
The set from which the items stored
in |
universe2 |
The set from which the items stored
in |
numCol |
The name of the numeric column used for data frame ordering. |
isHighTop |
Whether higher values in the numeric column correspond to top-ranked items. |
maxCutoffs |
Maximum number of cutoffs. If the input data frames
contain more cutoffs than this value, only |
mtMethod |
Multiple testing correction method. |
nCores |
Number of cores. If performing an overlap assessment between sets belonging to the same universe, it is recommended not to use parallelization (that is, leave this parameter as 1). |
type |
Type of overlap assessment. Choose between: two sets belonging to the same universe ('2N'), two sets belonging to different universes ('2MN'), three sets belonging to the same universe ('3MN'). |
A numeric value in [0, 1] representing the p-value of the overlap of the two objects.
pvalObjects(LETTERS[seq(2, 7)], LETTERS[seq(3, 19)], universe1=LETTERS)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.