| pvalObjectsCore | R Documentation |
This function computes the p-value of overlap for two or three objects.
pvalObjectsCore(
obj1,
obj2,
obj3 = NULL,
universe1,
universe2 = NULL,
numCol = NULL,
cutoff = NULL,
compFun = `>`,
type = c("2N", "2MN", "3N")
)
obj1 |
A data frame with a numeric column, or a character vector. |
obj2 |
A data frame with a numeric column, or a character vector. |
obj3 |
A data frame with a numeric column, or a character vector. |
universe1 |
The set from which the items stored
in |
universe2 |
The set from which the items stored
in |
numCol |
The name of the numeric column used for data frame ordering. |
A p-value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.