| pvalSets2MN | R Documentation |
This function computes the p-value of intersection of two subsets of sets M and N.
pvalSets2MN(a, b, m, n)
a |
A character vector. |
b |
A character vector. |
m |
Set from which |
n |
Set from which |
A thin wrapper around pvalCounts2MN.
A numeric value in [0, 1] representing the p-value of intersection of two subsets of sets M and N.
pvalSets2MN(LETTERS[seq(4, 10)],
LETTERS[seq(7, 15)],
LETTERS[seq(19)],
LETTERS[seq(6, 26)])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.