| vChoose | R Documentation |
This function computes the prime factor decomposition of the binomial coefficient.
vChoose(n, k)
n |
Total number of elements. |
k |
Number of selected elements. |
A vector in which positions represent prime numbers (that is, the first position corresponds to 2, the second position corresponds to 3, the third position corresponds to 5, etc.) and values represent their exponents in the factorial decomposition.
vChoose(8, 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.